@@ -84,7 +84,7 @@ void PowerDevilApp::init()
     }
 
     // not parenting Core to PowerDevilApp as it is the deleted too late on teardown
-    // where the X connection is already lost leading to a a crash (Bug 371127)
+    // where the X connection is already lost leading to a crash (Bug 371127)
     m_core = new PowerDevil::Core(nullptr/*, KComponentData(aboutData)*/);
 
     connect(m_core, SIGNAL(coreReady()), this, SLOT(onCoreReady()));
@@ -101,7 +101,7 @@ void PowerDevilApp::init()
     }
 
     QFileInfo backendFileInfo;
-    Q_FOREACH (const QFileInfo &f, fileInfos) {
+    for (const QFileInfo &f : qAsConst(fileInfos)) {
         if (f.baseName().toLower() == QLatin1String("powerdevilupowerbackend")) {
             backendFileInfo = f;
             break;
