@@ -19,7 +19,7 @@
 
 #include "ErrorOverlay.h"
 
-#include <QtCore/QEvent>
+#include <QEvent>
 #include <QLabel>
 #include <QVBoxLayout>
 #include <QIcon>
@@ -106,5 +106,3 @@ bool ErrorOverlay::eventFilter(QObject * object, QEvent * event)
     }
     return QWidget::eventFilter(object, event);
 }
-
-#include "ErrorOverlay.moc"
