@@ -93,7 +93,8 @@ void GeneralPage::fillUi()
     bool hasPowerSupplyBattery = false;
     bool hasPeripheralBattery = false;
 
-    Q_FOREACH (const Solid::Device &device, Solid::Device::listFromType(Solid::DeviceInterface::Battery, QString())) {
+    const auto devices = Solid::Device::listFromType(Solid::DeviceInterface::Battery, QString());
+    for (const Solid::Device &device : devices) {
         const Solid::Battery *b = qobject_cast<const Solid::Battery*> (device.asDeviceInterface(Solid::DeviceInterface::Battery));
         if (b->isPowerSupply()) {
             hasPowerSupplyBattery = true;
